@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.cpp,v 1.50.2.7 2005/06/05 09:36:06 chpe Exp $
+ *  $Id: EventContext.cpp,v 1.60 2005/08/17 17:19:29 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -56,6 +56,10 @@
 #include <nsIDOMNodeList.h>
 #include <nsIDOMDocumentView.h>
 #include <nsIDOMAbstractView.h>
+#include <nsIDOMNSHTMLDocument.h>
+#include <nsIDOMNSUIEvent.h>
+#include <nsIDOMHTMLSelectElement.h>
+#include <nsIDOMHTMLIsIndexElement.h>
 
 #ifdef ALLOW_PRIVATE_API
 #include <nsITextToSubURI.h>
@@ -1005,3 +1009,82 @@ nsresult EventContext::SetURIProperty (nsIDOMNode *node, const char *name, const
 	NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, cValue);
 	return SetURIProperty (node, name, cValue);
 }
+
+/* static */
+PRBool
+EventContext::CheckKeyPress (nsIDOMKeyEvent *aEvent)
+{
+	PRBool retval = PR_FALSE;
+
+	/* make sure the event is trusted */
+	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aEvent));
+	NS_ENSURE_TRUE (nsEvent, retval);
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return retval;
+
+	/* check for alt/ctrl */
+	PRBool isCtrl = PR_FALSE, isAlt = PR_FALSE;
+	aEvent->GetCtrlKey (&isCtrl);
+	aEvent->GetAltKey (&isAlt);
+	if (isCtrl || isAlt) return retval;
+
+	nsCOMPtr<nsIDOMNSUIEvent> uiEvent (do_QueryInterface (aEvent));
+	NS_ENSURE_TRUE (uiEvent, retval);
+
+	/* check for already handled event */
+	PRBool isPrevented = PR_FALSE;
+	uiEvent->GetPreventDefault (&isPrevented);
+	if (isPrevented) return retval;
+
+	/* check for form controls */
+	nsresult rv;
+	nsCOMPtr<nsIDOMEventTarget> target;
+	rv = aEvent->GetTarget (getter_AddRefs (target));
+	NS_ENSURE_SUCCESS (rv, retval);
+
+	nsCOMPtr<nsIDOMHTMLElement> element (do_QueryInterface (target, &rv));
+	NS_ENSURE_SUCCESS (rv, retval);
+
+	nsCOMPtr<nsIDOMHTMLInputElement> inputElement (do_QueryInterface (element));
+	if (inputElement)
+	{
+		nsEmbedString type;
+		inputElement->GetType (type);
+
+		nsEmbedCString (cType);
+		NS_UTF16ToCString (type, NS_CSTRING_ENCODING_UTF8, cType);
+
+		if (g_ascii_strcasecmp (cType.get(), "text") == 0 ||
+		    g_ascii_strcasecmp (cType.get(), "password") == 0 ||
+		    g_ascii_strcasecmp (cType.get(), "file") == 0) return retval;
+	}
+
+	nsCOMPtr<nsIDOMHTMLTextAreaElement> textArea;
+	nsCOMPtr<nsIDOMHTMLSelectElement> selectElement;
+	nsCOMPtr<nsIDOMHTMLIsIndexElement> indexElement;
+
+	if ((textArea = do_QueryInterface (element)) ||
+	    (selectElement = do_QueryInterface (element)) ||
+	    (indexElement = do_QueryInterface (element))) return retval;
+
+	/* check for design mode */
+	nsCOMPtr<nsIDOMDocument> doc;
+	rv = element->GetOwnerDocument (getter_AddRefs (doc));
+	NS_ENSURE_SUCCESS (rv, retval);
+
+	nsCOMPtr<nsIDOMNSHTMLDocument> htmlDoc (do_QueryInterface (doc, &rv));
+	/* FIXME: return PR_TRUE here ? */
+	if (NS_FAILED (rv)) return retval; /* it's okay not to be a HTML document */
+
+	nsEmbedString uDesign;
+	rv = htmlDoc->GetDesignMode (uDesign);
+	NS_ENSURE_SUCCESS (rv, retval);
+
+	nsEmbedCString design;
+	NS_UTF16ToCString (uDesign, NS_CSTRING_ENCODING_UTF8, design);
+
+	retval = g_ascii_strcasecmp (design.get(), "on") != 0;
+
+	return retval;
+}
