@@ -6,7 +6,15 @@
 
 G_BEGIN_DECLS
 
-/* BOOLEAN:ENUM,STRING,STRING,STRING (../../lib/ephy-marshal.list:1) */
+/* BOOLEAN:BOXED (../../lib/ephy-marshal.list:1) */
+extern void ephy_marshal_BOOLEAN__BOXED (GClosure     *closure,
+                                         GValue       *return_value,
+                                         guint         n_param_values,
+                                         const GValue *param_values,
+                                         gpointer      invocation_hint,
+                                         gpointer      marshal_data);
+
+/* BOOLEAN:ENUM,STRING,STRING,STRING (../../lib/ephy-marshal.list:2) */
 extern void ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -14,7 +22,7 @@ extern void ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* BOOLEAN:OBJECT (../../lib/ephy-marshal.list:2) */
+/* BOOLEAN:OBJECT (../../lib/ephy-marshal.list:3) */
 extern void ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -22,7 +30,15 @@ extern void ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* BOOLEAN:STRING,STRING (../../lib/ephy-marshal.list:3) */
+/* BOOLEAN:STRING (../../lib/ephy-marshal.list:4) */
+extern void ephy_marshal_BOOLEAN__STRING (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data);
+
+/* BOOLEAN:STRING,STRING (../../lib/ephy-marshal.list:5) */
 extern void ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -30,7 +46,7 @@ extern void ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* BOOLEAN:STRING,STRING,STRING (../../lib/ephy-marshal.list:4) */
+/* BOOLEAN:STRING,STRING,STRING (../../lib/ephy-marshal.list:6) */
 extern void ephy_marshal_BOOLEAN__STRING_STRING_STRING (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -38,7 +54,7 @@ extern void ephy_marshal_BOOLEAN__STRING_STRING_STRING (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* BOOLEAN:VOID (../../lib/ephy-marshal.list:5) */
+/* BOOLEAN:VOID (../../lib/ephy-marshal.list:7) */
 extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -46,7 +62,7 @@ extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* OBJECT:OBJECT,FLAGS (../../lib/ephy-marshal.list:6) */
+/* OBJECT:OBJECT,FLAGS (../../lib/ephy-marshal.list:8) */
 extern void ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -54,7 +70,7 @@ extern void ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* OBJECT:STRING,OBJECT,FLAGS (../../lib/ephy-marshal.list:7) */
+/* OBJECT:STRING,OBJECT,FLAGS (../../lib/ephy-marshal.list:9) */
 extern void ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -62,7 +78,15 @@ extern void ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
 
-/* STRING:VOID (../../lib/ephy-marshal.list:8) */
+/* STRING:STRING,STRING (../../lib/ephy-marshal.list:10) */
+extern void ephy_marshal_STRING__STRING_STRING (GClosure     *closure,
+                                                GValue       *return_value,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint,
+                                                gpointer      marshal_data);
+
+/* STRING:VOID (../../lib/ephy-marshal.list:11) */
 extern void ephy_marshal_STRING__VOID (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -70,10 +94,10 @@ extern void ephy_marshal_STRING__VOID (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* VOID:ENUM (../../lib/ephy-marshal.list:9) */
+/* VOID:ENUM (../../lib/ephy-marshal.list:12) */
 #define ephy_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
 
-/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:10) */
+/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:13) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -81,7 +105,7 @@ extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:11) */
+/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:14) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -89,7 +113,7 @@ extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:STRING,FLAGS (../../lib/ephy-marshal.list:12) */
+/* VOID:STRING,FLAGS (../../lib/ephy-marshal.list:15) */
 extern void ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -97,7 +121,7 @@ extern void ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:STRING,INT (../../lib/ephy-marshal.list:13) */
+/* VOID:STRING,INT (../../lib/ephy-marshal.list:16) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -105,7 +129,7 @@ extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:STRING,STRING (../../lib/ephy-marshal.list:14) */
+/* VOID:STRING,STRING (../../lib/ephy-marshal.list:17) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -113,6 +137,14 @@ extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
+/* VOID:STRING,STRING,STRING (../../lib/ephy-marshal.list:18) */
+extern void ephy_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
+                                                     GValue       *return_value,
+                                                     guint         n_param_values,
+                                                     const GValue *param_values,
+                                                     gpointer      invocation_hint,
+                                                     gpointer      marshal_data);
+
 G_END_DECLS
 
 #endif /* __ephy_marshal_MARSHAL_H__ */
