@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.72 2005/07/26 17:41:04 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.74 2005/08/20 22:23:16 chpe Exp $
  */
 
 #include "config.h"
@@ -197,14 +197,21 @@ ephy_topic_action_sync_label (GtkAction *gaction,
 	if (GTK_IS_TOOL_ITEM (proxy))
 	{
 		GtkWidget *label = NULL;
-		char *title;
+		char *title, *separator;
 
 		label = g_object_get_data (G_OBJECT (proxy), "label");
 		g_return_if_fail (label != NULL);
 
 		g_object_get (G_OBJECT (action), "label", &title, NULL);
+		g_return_if_fail (label != NULL);
 
-		gtk_label_set_label (GTK_LABEL (label), title);
+		/* In case this is a multi-hierarchy topic, we only want to
+		 * display the leaf name. See bug #310963.
+		 */
+		separator = g_strrstr (title, BOOKMARKS_HIERARCHY_SEP);
+
+		gtk_label_set_label (GTK_LABEL (label),
+				     separator != NULL ? separator + strlen(BOOKMARKS_HIERARCHY_SEP) : title);
 
 		g_free (title);
 	}
