@@ -24,6 +24,8 @@ GType ephy_new_tab_flags_get_type (void);
 /* --- ephy-tab.h --- */
 #define EPHY_TYPE_TAB_NAVIGATION_FLAGS ephy_tab_navigation_flags_get_type()
 GType ephy_tab_navigation_flags_get_type (void);
+#define EPHY_TYPE_TAB_ADDRESS_EXPIRE ephy_tab_address_expire_get_type()
+GType ephy_tab_address_expire_get_type (void);
 
 /* --- ephy-navigation-action.h --- */
 #define EPHY_TYPE_NAVIGATION_DIRECTION ephy_navigation_direction_get_type()
